@@ -2,7 +2,7 @@ package Net::SMTP::Verify::App;
 
 use Moose;
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 # ABSTRACT: commandline wrapper class for Net::SMTP::Verify
 
 extends 'Net::SMTP::Verify';
@@ -33,6 +33,11 @@ has '+tlsa' => (
   cmd_aliases => 'a',
   documentation => 'lookup if TLSA record is available',
 );
+has '+openpgpkey' => (
+  traits => [ 'Getopt' ],
+  cmd_aliases => 'o',
+  documentation => 'lookup if OPENPGPKEY records are available',
+);
 has '+debug' => (
   traits => [ 'Getopt' ],
   cmd_aliases => 'd',
@@ -95,7 +100,7 @@ Net::SMTP::Verify::App - commandline wrapper class for Net::SMTP::Verify
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 AUTHOR
 
